pub struct ModelUpgrade {
pub from_id: String,
pub from_name: String,
pub to_id: String,
pub to_name: String,
pub reason: String,
pub target_runtime: Option<String>,
pub target_runtime_requirement: Option<String>,
pub minimum_runtimes: Vec<ModelRuntimeRequirement>,
pub target_available: bool,
pub target_pullable: bool,
pub remove_old_supported: bool,
}Expand description
A curated replacement for a local model that is installed but no longer the preferred model in its line.
Fields
from_id: Stringfrom_name: Stringto_id: Stringto_name: Stringreason: Stringtarget_runtime: Option<String>target_runtime_requirement: Option<String>minimum_runtimes: Vec<ModelRuntimeRequirement>target_available: booltarget_pullable: boolremove_old_supported: boolTrait Implementations
Sourceimpl Clone for ModelUpgrade
impl Clone for ModelUpgrade
Sourcefn clone(&self) -> ModelUpgrade
fn clone(&self) -> ModelUpgrade
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelUpgrade
impl Debug for ModelUpgrade
Sourceimpl<'de> Deserialize<'de> for ModelUpgrade
impl<'de> Deserialize<'de> for ModelUpgrade
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more