pub struct FallbackFrom {
pub candidate: String,
pub reason: FallbackReason,
}Expand description
A candidate the fallback chain moved past, and why.
Fields
candidate: StringThe candidate’s name, as the chain knew it.
reason: FallbackReasonTrait Implementations
Sourceimpl Clone for FallbackFrom
impl Clone for FallbackFrom
Sourceimpl Debug for FallbackFrom
impl Debug for FallbackFrom
Sourceimpl<'de> Deserialize<'de> for FallbackFrom
impl<'de> Deserialize<'de> for FallbackFrom
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FallbackFrom
Sourceimpl JsonSchema for FallbackFrom
impl JsonSchema for FallbackFrom
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FallbackFrom
impl PartialEq for FallbackFrom
Sourceimpl Serialize for FallbackFrom
impl Serialize for FallbackFrom
impl StructuralPartialEq for FallbackFrom